@@ -184,6 +184,7 @@ save_variables__sub(FILE *fp)
 		 && strncmp(udv->udv_name,"MOUSE_",6)
 		 && strncmp(udv->udv_name,"$",1)
 		 && (strncmp(udv->udv_name,"ARG",3) || (strlen(udv->udv_name) != 4))
+		 && strncmp(udv->udv_name,"Inf",4)
 		 && strncmp(udv->udv_name,"NaN",4)) {
 		    fprintf(fp, "%s = ", udv->udv_name);
 		    disp_value(fp, &(udv->udv_value), TRUE);
@@ -627,8 +628,15 @@ set encoding %s\n\
     if (!numeric_locale && !decimalsign)
 	fprintf(fp, "unset decimalsign\n");
 
-    fprintf(fp, "%sset micro\n", use_micro ? "" : "un");
     fprintf(fp, "%sset minussign\n", use_minus_sign ? "" : "un");
+    if (use_micro && micro_user)
+	fprintf(fp, "set micro \"%s\"\n", micro_user);
+    else
+	fprintf(fp, "%sset micro\n", use_micro ? "" : "un");
+    if (imaginary_user)
+	fprintf(fp, "set imaginary_i \"%s\"\n", imaginary_user);
+    else
+	fprintf(fp, "set imaginary_i\n");
 
     fputs("set view ", fp);
     if (splot_map == TRUE)
@@ -1516,6 +1524,8 @@ save_link(FILE *fp, AXIS *this_axis)
 	    fprintf(fp, "inverse %s ", this_axis->linked_to_primary->link_udf->definition);
 	fputs("\n", fp);
     }
+    if (this_axis->forced_log_link)
+	fprintf(fp, "set link %s # forced log link\n", axis_name(this_axis->index));
 }
 
 void
