@@ -61,9 +61,11 @@ char degree_sign[8] = "°";
 /* encoding-specific characters used by gprintf() */
 const char *micro = NULL;
 const char *minus_sign = NULL;
+const char *i_symbol = NULL;
 TBOOLEAN use_micro = FALSE;
 TBOOLEAN use_minus_sign = FALSE;
 char *micro_user = NULL;
+char *imaginary_user = NULL;
 
 /* Holds the name of the current LC_NUMERIC as set by "set decimal locale" */
 char *numeric_locale = NULL;
@@ -568,7 +570,7 @@ gprintf_value(
 	format = DEF_FORMAT;
 
     /* By default we wrap numbers output to latex terminals in $...$ */
-    if (!strcmp(format, DEF_FORMAT)  && !table_mode
+    if (is_def_format(format) && !table_mode
     &&  ((term->flags & TERM_IS_LATEX)))
 	format = DEF_FORMAT_LATEX;
 
@@ -652,7 +654,7 @@ gprintf_value(
 		TBOOLEAN bracket_flag = FALSE;
 		snprintf(tmp, 240, temp, x); /* magic number alert: why 240? */
 		for (i=j=0; tmp[i] && (i < LOCAL_BUFFER_SIZE); i++) {
-		    if (tmp[i]=='E' || tmp[i]=='e') {
+		    if (tmp[i] == 'E' || tmp[i] == 'e') {
 			if ((term-> flags & TERM_IS_LATEX)) {
 			    if (*format == 'h') {
 				strcpy(&tmp2[j], "\\times");
@@ -663,20 +665,28 @@ gprintf_value(
 			    }
 			} else switch (encoding) {
 			    case S_ENC_UTF8:
-				strcpy(&tmp2[j], "\xc3\x97"); /* UTF character '×' */
-				j+= 2;
+				if (*format == 'h') {
+				    strcpy(&tmp2[j], "\xc3\x97"); /* Unicode 'times sign' */
+				    j+= 2;
+				} else if ((term->flags & TERM_IS_POSTSCRIPT)) {
+				    strcpy(&tmp2[j], "\xc2\xb7"); /* Unicode 'middle dot' */
+				    j+= 2;
+				} else {
+				    strcpy(&tmp2[j], "\xE2\x8B\x85"); /* Unicode 'dot operator' */
+				    j+= 3;
+				}
 				break;
 			    case S_ENC_CP1252:
-				tmp2[j++] = (*format=='h') ? 0xd7 : 0xb7;
+				tmp2[j++] = (*format == 'h') ? 0xd7 : 0xb7;
 				break;
 			    case S_ENC_ISO8859_1:
 			    case S_ENC_ISO8859_2:
 			    case S_ENC_ISO8859_9:
 			    case S_ENC_ISO8859_15:
-				tmp2[j++] = (*format=='h') ? 0xd7 : '*';
+				tmp2[j++] = (*format == 'h') ? 0xd7 : '*';
 				break;
 			    default:
-				tmp2[j++] = (*format=='h') ? 'x' : '*';
+				tmp2[j++] = (*format == 'h') ? 'x' : '*';
 				break;
 			}
 
@@ -929,12 +939,45 @@ gprintf_value(
 		break;
 	    }
 	    /*}}} */
+	    /*{{{  C or Ci --- complex value */
+	case 'C':
+	    {
+		double vr = real(v);
+		double vi = imag(v);
+		t[0] = 'g';
+		t[1] = '\0';
+		if (format[1] == 'i') {
+		    format++;
+		    /* complex value printed as a + bi */
+		    if (vr != 0.0 || vi == 0.0)
+			dest += snprintf(dest, remaining_space, temp, vr);
+		    if (vi != 0.0) {
+			if (vr == 0.0) {
+			    dest += snprintf(dest, remaining_space, temp, vi);
+			} else {
+			    dest += snprintf(dest, remaining_space, (vi < 0) ? " - " : " + ");
+			    dest += snprintf(dest, remaining_space, temp, fabs(vi));
+			}
+			dest += snprintf(dest, remaining_space, "%s",
+					imaginary_user ? imaginary_user : "i");
+		    }
+		} else {
+		    /* complex value printed as {a, b} */
+		    dest += snprintf(dest, remaining_space, "{");
+		    dest += snprintf(dest, remaining_space, temp, vr);
+		    dest += snprintf(dest, remaining_space, ", ");
+		    dest += snprintf(dest, remaining_space, temp, vi);
+		    dest += snprintf(dest, remaining_space, "}");
+		}
+		break;
+	    }
+	    /*}}} */
 	default:
 	   int_error(NO_CARET, "Bad format character");
 	} /* switch */
 	/*}}} */
 
-	if (got_hash && (format != strpbrk(format,"oeEfFgG")))
+	if (got_hash && (format != strpbrk(format,"oeEfFgGhHC")))
 	   int_error(NO_CARET, "Bad format character");
 
     /* change decimal '.' to the actual entry in decimalsign */
@@ -1582,7 +1625,8 @@ num_to_str(double r)
     sprintf(s[j], "%.15g", r);
     if (strchr(s[j], '.') == NULL &&
 	strchr(s[j], 'e') == NULL &&
-	strchr(s[j], 'E') == NULL)
+	strchr(s[j], 'E') == NULL &&
+	!isinf(r) && !isnan(r))
 	strcat(s[j], ".0");
 
     return s[j];
